@@ -1,4 +1,4 @@
-# $Id: crt.py 926 2014-06-05 08:54:32Z mwall $
+# $Id: crt.py 927 2014-06-05 16:14:50Z mwall $
 # Copyright 2013 Matthew Wall
 
 # Emit loop data to file in Cumulus realtime format.
@@ -146,7 +146,7 @@ def calc10MinAvgWindDir(archive, ts):
 def calcWindRun(archive, ts):
     run = 0
     sod_ts = weeutil.weeutil.startOfDay(ts)
-    for row in archive.genSql("SELECT interval,windSpeed FROM archive "
+    for row in archive.genSql("SELECT `interval`,windSpeed FROM archive "
                               "WHERE dateTime>? AND dateTime<=?", 
                               (sod_ts, ts)):
         run += row[1] * (row[0] / 60)
